==> dart_blocks-0.4.61.tar.gz: lib/dart_blocks/user_analytics/user_analytics_web.dart <==
import 'dart:async';
import 'package:dart_blocks/dart_blocks/nuntio_client.dart';
import 'package:flutter/cupertino.dart';
import 'package:nuntio_blocks/block_user.pb.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:uuid/uuid.dart';
import 'dart:html' as html;

class UserAnalytics extends StatefulWidget {
  final Widget child;

  UserAnalytics({required this.child});

  @override
  State<UserAnalytics> createState() => _UserAnalyticsState();
}

class _UserAnalyticsState extends State<UserAnalytics> {
  // init
  Timer? _timer;
  final String _activeKeySeconds = "nuntio-blocks-active-seconds";
  final String _activeKeyId = "nuntio-blocks-active-id";
  final String _activeKeyUserId = "nuntio-blocks-active-user-id";

  // _activeId is used to record how long user is active
  String _activeId = "";

  Future<void> _measureUserTime(SharedPreferences prefs) async {
    try {
      if (_timer != null && _timer?.isActive == true) {
        _timer!.cancel();
      }
      await prefs.remove(_activeId);
      await prefs.remove(_activeKeyUserId);
      await prefs.remove(_activeKeyId);
    } catch (e) {
      print(e);
    }
    // init new values
    const int _interval = 2;
    int _current = 0;
    _activeId = Uuid().v4();
    // every 1 seconds record time time. Send average of these every 5 minute to server.
    _timer = Timer.periodic(Duration(seconds: _interval), (timer) async {
      // make sure shared prefs is available
      User _currentUser = await NuntioClient.userBlock.getCurrentUser();
      if (_currentUser.id != "" && _activeId != "") {
        if ((prefs.getString(_activeKeyUserId) ?? "") == "") {
          await prefs.setString(_activeKeyUserId, _currentUser.id);
          await prefs.setString(_activeKeyId, _activeId);
        }
        _current += _interval;
        await prefs.setInt(_activeKeySeconds, _current);
      }
    });
  }

  Future<void> initializeAnalytics() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    try {
      final _prevTotalSeconds = prefs.getInt(_activeKeySeconds) ?? 0;
      final _prevActiveId = prefs.getString(_activeKeyId) ?? "";
      final _prevActiveUserId = prefs.getString(_activeKeyUserId) ?? "";
      if (_prevTotalSeconds > 0 &&
          _prevActiveId != "" &&
          _prevActiveUserId != "") {
        print("s:" +
            _prevTotalSeconds.toString() +
            " " +
            "active ID:" +
            _prevActiveId +
            " " +
            "user ID:" +
            _prevActiveUserId);
        await NuntioClient.userBlock.recordActiveMeasurement(
            _prevTotalSeconds, _prevActiveId, _prevActiveUserId);
      }
    } catch (e) {
      print("an error occured");
      print(e);
      print("an error occurred");
    }
    _measureUserTime(prefs);
  }

  @override
  void initState() {
    html.window.onBeforeUnload.listen((event) async {
      await initializeAnalytics();
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return widget.child;
  }
}

==> dart_blocks-0.4.62.tar.gz: lib/dart_blocks/user_analytics/user_analytics_web.dart <==
import 'dart:async';
import 'package:dart_blocks/dart_blocks/nuntio_client.dart';
import 'package:flutter/cupertino.dart';
import 'package:nuntio_blocks/block_user.pb.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:uuid/uuid.dart';
import 'dart:html' as html;

class UserAnalytics extends StatefulWidget {
  final Widget child;

  UserAnalytics({required this.child});

  @override
  State<UserAnalytics> createState() => _UserAnalyticsState();
}

class _UserAnalyticsState extends State<UserAnalytics> {
  // init
  late Future<void> initializeAnalyticsFuture;
  Timer? _timer;
  final String _activeKeySeconds = "nuntio-blocks-active-seconds";
  final String _activeKeyId = "nuntio-blocks-active-id";
  final String _activeKeyUserId = "nuntio-blocks-active-user-id";

  // _activeId is used to record how long user is active
  String _activeId = "";

  Future<void> _measureUserTime(SharedPreferences prefs) async {
    try {
      if (_timer != null && _timer?.isActive == true) {
        _timer!.cancel();
      }
      await prefs.remove(_activeId);
      await prefs.remove(_activeKeyUserId);
      await prefs.remove(_activeKeyId);
    } catch (e) {
      print(e);
    }
    // init new values
    const int _interval = 2;
    int _current = 0;
    _activeId = Uuid().v4();
    // every 1 seconds record time time. Send average of these every 5 minute to server.
    _timer = Timer.periodic(Duration(seconds: _interval), (timer) async {
      // make sure shared prefs is available
      User _currentUser = await NuntioClient.userBlock.getCurrentUser();
      if (_currentUser.id != "" && _activeId != "") {
        if ((prefs.getString(_activeKeyUserId) ?? "") == "") {
          await prefs.setString(_activeKeyUserId, _currentUser.id);
          await prefs.setString(_activeKeyId, _activeId);
        }
        _current += _interval;
        await prefs.setInt(_activeKeySeconds, _current);
      }
    });
  }

  Future<void> initializeAnalytics() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    _measureUserTime(prefs);
  }

  @override
  void initState() {
    initializeAnalyticsFuture = initializeAnalytics();
    html.window.onBeforeUnload.listen((event) async{
      try {
        SharedPreferences prefs = await SharedPreferences.getInstance();
        final _prevTotalSeconds = prefs.getInt(_activeKeySeconds) ?? 0;
        final _prevActiveId = prefs.getString(_activeKeyId) ?? "";
        final _prevActiveUserId = prefs.getString(_activeKeyUserId) ?? "";
        if (_prevTotalSeconds > 0 &&
            _prevActiveId != "" &&
            _prevActiveUserId != "") {
          print("s:" +
              _prevTotalSeconds.toString() +
              " " +
              "active ID:" +
              _prevActiveId +
              " " +
              "user ID:" +
              _prevActiveUserId);
          await NuntioClient.userBlock.recordActiveMeasurement(
              _prevTotalSeconds, _prevActiveId, _prevActiveUserId);
        }
      } catch (e) {
        print("an error occured");
        print(e);
        print("an error occurred");
      }
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<void>(
        future: initializeAnalyticsFuture,
        builder: (context, snapshot) {
          switch (snapshot.connectionState) {
            case ConnectionState.waiting:
              return CupertinoActivityIndicator();
            case ConnectionState.done:
              return widget.child;
            default:
              return Text("Error");
          }
        });
  }
}
